@@ -23,7 +23,7 @@ Hello_Applet::Hello_Applet():
 
 void Hello_Applet::callback()
 {
-    Gnome::Dialog::ok_dialog("Hello!");
+    Gnome::Dialogs::ok ("Hello!");
 }
 
 int main(int argc, char **argv)
